You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2013/01/02 06:21:08 UTC

svn commit: r1427655 [23/35] - in /river/jtsk/skunk/qa_refactor/trunk/qa: ./ doc/ src/com/sun/jini/qa/harness/ src/com/sun/jini/test/impl/discoverymanager/ src/com/sun/jini/test/impl/discoveryproviders/ src/com/sun/jini/test/impl/end2end/e2etest/ src/c...

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/DiscardUnreachable.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/DiscardUnreachable.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/DiscardUnreachable.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/DiscardUnreachable.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.test.spec.discoverys
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.DiscoveryProtocolSimulator;
 import com.sun.jini.test.share.DiscoveryServiceUtil;
@@ -80,11 +81,12 @@ public class DiscardUnreachable extends 
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         discardType = ACTIVE_DISCARDED;
         regInfoMap = registrationMap;
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
@@ -155,7 +157,7 @@ public class DiscardUnreachable extends 
                 regProxy = (ServiceRegistrar)curObj;
             }//endif
             /* destroy lookup service i */
-            manager.destroyService(regProxy);
+            getManager().destroyService(regProxy);
         }//end loop
         announcementsStopped = true;
     }//end terminateAllLookups

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedGroups.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import net.jini.core.discovery.LookupLoc
 import java.util.HashMap;
 import java.util.Map;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that, upon registration, so-called "late-joiner"
@@ -73,12 +74,13 @@ public class LateRegsNotifiedGroups exte
     /** Performs actions necessary to prepare for execution of the 
      *  current test. Populates the sets of group and/or locators to use.
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         logger.log(Level.FINE, "setup()");
         groupsToDiscover = getGroupsToDiscover(useOnlyGroupDiscovery);
         locsToDiscover = getLocatorsToDiscover(useOnlyGroupDiscovery);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedLocs.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedLocs.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedLocs.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedLocs.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.discovery
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that, upon registration, so-called "late-joiner"
@@ -63,12 +64,13 @@ public class LateRegsNotifiedLocs extend
     /** Performs actions necessary to prepare for execution of the 
      *  current test. Populates the sets of group and/or locators to use.
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         logger.log(Level.FINE, "setup()");
         groupsToDiscover = getGroupsToDiscover(useOnlyLocDiscovery);
         locsToDiscover = getLocatorsToDiscover(useOnlyLocDiscovery);
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class LateRegsNotifiedLocs
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOn2SetGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOn2SetGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnAddGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnAddGroups.java Wed Jan  2 05:20:52 2013
@@ -78,12 +78,12 @@ public class LateRegsNotifiedOnAddGroups
      * <li> creates a first set of registration(s) with the lookup discovery
      *      service, requesting the discovery of the first set of groups,
      *      which should equal the member groups of the first lookup service(s)
-     *      started in setup
+     *      started in construct
      * <li> verifies that the listener for the first registration(s) receives
      *      the appropriate remote discovery event for the first set of groups
      * <li> on each of the initial registration(s) calls addGroups, requesting
      *      that the discovery of the second set of groups, which should equal
-     *      the member groups of the second lookup service(s) started in setup
+     *      the member groups of the second lookup service(s) started in construct
      * <li> verifies that the listener for the first registration(s) receive
      *      the appropriate remote discovery event for the second set of groups
      * <li> creates a second set of registration(s) with the lookup discovery

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnAddLocs.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnAddLocs.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnAddLocs.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnAddLocs.java Wed Jan  2 05:20:52 2013
@@ -78,14 +78,14 @@ public class LateRegsNotifiedOnAddLocs e
      * <li> creates a first set of registration(s) with the lookup discovery
      *      service, requesting the discovery of the first set of locators,
      *      which should equal the locators of the first lookup service(s)
-     *      started in setup
+     *      started in construct
      * <li> verifies that the listener for the first registration(s) receives
      *      the appropriate remote discovery event for the first set of
      *      locators
      * <li> on each of the initial registration(s) calls addLocators,
      *      requesting that the discovery of the second set of locators, which
      *      should equal the locators of the second lookup service(s) started
-     *      in setup
+     *      in construct
      * <li> verifies that the listener for the first registration(s) receive
      *      the appropriate remote discovery event for the second set of
      *      locators

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnSetGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnSetGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnSetGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnSetGroups.java Wed Jan  2 05:20:52 2013
@@ -84,7 +84,7 @@ public class LateRegsNotifiedOnSetGroups
      * <li> create a first set of registration(s) with the lookup discovery
      *      service, requesting that NO_GROUPS and no locators be discovered
      * <li> calls setGroups, requesting the discovery of the member groups of
-     *      the lookup service(s) started in setup
+     *      the lookup service(s) started in construct
      * <li> verifies that the discovery process is working for the first
      *      registration by waiting for the expected discovery events
      * <li> creates a second set of registration(s) with the lookup discovery

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnSetLocs.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnSetLocs.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnSetLocs.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnSetLocs.java Wed Jan  2 05:20:52 2013
@@ -70,7 +70,7 @@ public class LateRegsNotifiedOnSetLocs e
      * <li> create a first set of registration(s) with the lookup discovery
      *      service, requesting that NO_GROUPS and no locators be discovered
      * <li> calls setLocators, requesting the discovery of the locators of
-     *      the lookup service(s) started in setup
+     *      the lookup service(s) started in construct
      * <li> verifies that the discovery process is working for the first
      *      registration by waiting for the expected discovery events
      * <li> creates a second set of registration(s) with the lookup discovery

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/MulticastMonitorStop.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/MulticastMonitorStop.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/MulticastMonitorStop.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/MulticastMonitorStop.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.DiscoveryProtocolSimulator;
 import com.sun.jini.test.share.DiscoveryServiceUtil;
@@ -70,11 +71,12 @@ public class MulticastMonitorStop extend
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         terminate = false;
         discardType = PASSIVE_DISCARDED;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class MulticastMonitorStop
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/MulticastMonitorTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/MulticastMonitorTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/MulticastMonitorTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/MulticastMonitorTerminate.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.test.spec.discoverys
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.DiscoveryProtocolSimulator;
 import com.sun.jini.test.share.DiscoveryServiceUtil;
@@ -76,8 +77,8 @@ public class MulticastMonitorTerminate e
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         logger.log(Level.FINE, 
                         "number of announcements to wait for    -- "
                         +minNAnnouncements);
@@ -93,7 +94,8 @@ public class MulticastMonitorTerminate e
                         "stop announcements, will not destroy lookups");
         }
         discardType = COMM_DISCARDED;
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>
@@ -187,7 +189,7 @@ public class MulticastMonitorTerminate e
                 regProxy = (ServiceRegistrar)curObj;
             }//endif
             if(terminate) {//destroy lookups individually
-                manager.destroyService(regProxy);
+                getManager().destroyService(regProxy);
             } else {//don't terminate, replace member groups to gen discard evt
                 logger.log(Level.FINE, "lookup service "+i+" -- "
                                   +"replace member groups to "

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RegsNotifiedOnRemoveGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RegsNotifiedOnRemoveGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RegsNotifiedOnRemoveGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RegsNotifiedOnRemoveGroups.java Wed Jan  2 05:20:52 2013
@@ -85,7 +85,7 @@ public class RegsNotifiedOnRemoveGroups 
      * <li> creates two separate sets of registrations with the lookup
      *      discovery service, requesting the discovery of both sets of groups
      *      which should, respectively, equal the member groups of both
-     *      lookup services started in setup
+     *      lookup services started in construct
      * <li> verifies that the listeners for the registrations in either set
      *      receive the appropriate remote discovery event for the both sets
      *      of groups

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RegsNotifiedOnRemoveLocs.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RegsNotifiedOnRemoveLocs.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RegsNotifiedOnRemoveLocs.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RegsNotifiedOnRemoveLocs.java Wed Jan  2 05:20:52 2013
@@ -86,7 +86,7 @@ public class RegsNotifiedOnRemoveLocs ex
      * <li> creates two separate sets of registrations with the lookup
      *      discovery service, requesting the discovery of both sets of
      *      locators which should, respectively, equal the locators of the
-     *      lookup services started in setup
+     *      lookup services started in construct
      * <li> verifies that the listeners for the registrations in either set
      *      receive the appropriate remote discovery event for the both sets
      *      of locators

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveGroupsAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveGroupsAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveGroupsAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveGroupsAll.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.discovery
 
 import java.util.Map;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>removeGroups</code> method, this class verifies
@@ -57,10 +58,11 @@ public class RemoveGroupsAll extends Rem
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         groupsMap = getPassiveCommDiscardMap(useOnlyGroupDiscovery);
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class RemoveGroupsAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveGroupsSome.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveGroupsSome.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveGroupsSome.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveGroupsSome.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.test.spec.discoverys
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.DiscoveryProtocolSimulator;
 import com.sun.jini.test.share.GroupsUtil;
@@ -84,13 +85,14 @@ public class RemoveGroupsSome extends Ab
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         useDiscoveryList = useGroupAndLocDiscovery0;
         groupsMap        = getPassiveCommDiscardMap(useDiscoveryList);
         discardType      = ACTIVE_DISCARDED;
         regInfoMap       = registrationMap;
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsAll.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.DiscoveryProtocolSimulator;
 import com.sun.jini.test.share.GroupsUtil;
@@ -81,10 +82,11 @@ public class RemoveLocatorsAll extends R
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         locatorsMap = getModLocatorsDiscardMap(useDiscoveryList);
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class RemoveLocatorsAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsFullyQualified.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsFullyQualified.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsFullyQualified.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsFullyQualified.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.discovery
 
 import com.sun.jini.test.spec.discoveryservice.AbstractBaseTest;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.test.share.LocatorsUtil;
 
 import net.jini.discovery.LookupDiscoveryRegistration;
@@ -155,8 +156,8 @@ public class RemoveLocatorsFullyQualifie
     protected HashMap regInfoMap = registrationMap;
 
     /** Retrieves additional configuration values. */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 //      debugFlag = true;
 //      displayOn = true;
         useDiscoveryList = useOnlyLocDiscovery;
@@ -198,7 +199,8 @@ public class RemoveLocatorsFullyQualifie
             }
             logger.log(Level.FINE, "qualifiedLocs["+i+"] = "+qualifiedLocs[i]);
         }//end loop
-    }//end setup
+        return this;
+    }//end construct
 
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsSome.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsSome.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsSome.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/RemoveLocatorsSome.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.test.spec.discoverys
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.DiscoveryProtocolSimulator;
 import com.sun.jini.test.share.GroupsUtil;
@@ -88,13 +89,14 @@ public class RemoveLocatorsSome extends 
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         useDiscoveryList = useGroupAndLocDiscovery0;
         locatorsMap      = getModLocatorsDiscardMap(useDiscoveryList);
         discardType      = ACTIVE_DISCARDED; // want groups and locators
         regInfoMap       = registrationMap;
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetGroupsReplaceAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetGroupsReplaceAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetGroupsReplaceAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetGroupsReplaceAll.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.discovery
 
 import java.util.Map;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>setGroups</code> method, this class verifies
@@ -57,10 +58,11 @@ public class SetGroupsReplaceAll extends
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         groupsMap = getPassiveCommDiscardMap(useOnlyGroupDiscovery);
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class SetGroupsReplaceAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetGroupsReplaceSome.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetGroupsReplaceSome.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetGroupsReplaceSome.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetGroupsReplaceSome.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.test.spec.discoverys
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.DiscoveryProtocolSimulator;
 import com.sun.jini.test.share.GroupsUtil;
@@ -86,13 +87,14 @@ public class SetGroupsReplaceSome extend
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         useDiscoveryList = useGroupAndLocDiscovery0;
         groupsMap        = getPassiveCommDiscardMap(useDiscoveryList);
         discardType      = ACTIVE_DISCARDED;
         regInfoMap       = registrationMap;
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsFullyQualified.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsFullyQualified.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsFullyQualified.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsFullyQualified.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.GroupsUtil;
 import com.sun.jini.test.share.LocatorsUtil;
@@ -85,8 +86,8 @@ public class SetLocatorsFullyQualified e
     protected HashMap regInfoMap = registrationMap;
 
     /** Retrieves additional configuration values. */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 //      debugFlag = true;
 //      displayOn = true;
         useDiscoveryList = useOnlyLocDiscovery;
@@ -123,7 +124,8 @@ public class SetLocatorsFullyQualified e
             }
             logger.log(Level.FINE, "locsToSet["+i+"] = "+locsToSet[i]);
         }//end loop
-    }//end setup
+        return this;
+    }//end construct
 
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsReplaceAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsReplaceAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsReplaceAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsReplaceAll.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.DiscoveryProtocolSimulator;
 import com.sun.jini.test.share.GroupsUtil;
@@ -86,10 +87,11 @@ public class SetLocatorsReplaceAll exten
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         locatorsMap = getModLocatorsDiscardMap(useOnlyLocDiscovery);
-    }//end setup
+        return this;
+    }//end construct
 
 } //end class SetLocatorsReplaceAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsReplaceSome.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsReplaceSome.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsReplaceSome.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsReplaceSome.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.test.spec.discoverys
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.DiscoveryProtocolSimulator;
 import com.sun.jini.test.share.GroupsUtil;
@@ -88,13 +89,14 @@ public class SetLocatorsReplaceSome exte
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         useDiscoveryList = useGroupAndLocDiscovery0;
         locatorsMap      = getModLocatorsDiscardMap(useDiscoveryList);
         discardType      = ACTIVE_DISCARDED; // want groups and locators
         regInfoMap       = registrationMap;
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsToNone.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsToNone.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsToNone.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/SetLocatorsToNone.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.DiscoveryProtocolSimulator;
 import com.sun.jini.test.share.GroupsUtil;
@@ -87,13 +88,14 @@ public class SetLocatorsToNone extends A
     protected HashMap regInfoMap = registrationMap;
 
     /** Retrieves additional configuration values. */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 //      debugFlag = true;
 //      displayOn = true;
         useDiscoveryList = useOnlyLocDiscovery;
         discardType      = ACTIVE_DISCARDED;
-    }//end setup
+        return this;
+    }//end construct
 
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/CancelLease.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/CancelLease.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/CancelLease.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/CancelLease.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.test.spec.discoverys
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.test.share.DiscoveryServiceUtil;
@@ -79,8 +80,8 @@ public class CancelLease extends Abstrac
      *  that the registration is valid)
      *  Retrieves and stores the lease granted on the registration
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         String[] expectedGroups = getGroupsToDiscover();
         reg = DiscoveryServiceUtil.getRegistration
                                 (discoverySrvc,
@@ -97,12 +98,13 @@ public class CancelLease extends Abstrac
                                           (lease.getExpiration(),
                                            System.currentTimeMillis());
         logger.log(Level.FINE, "initial lease duration = "+duration);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      *  
      *  1. Requests the cancellation of the lease on the registration granted
-     *     during setup
+     *     during construct
      *  2. Verifies the lease is no longer valid by doing the following:
      *     a. attempts to retrieve the set of groups that the service
      *        will discover on behalf of the client; if the lease was

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/CancelLeaseMap.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/CancelLeaseMap.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/RenewLease.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/RenewLease.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import com.sun.jini.test.share.Discovery
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.discovery.LookupDiscoveryRegistration;
 
@@ -66,8 +67,8 @@ public class RenewLease extends Abstract
      *  Starts one lookup discovery service.
      *  Requests a registration with the service.
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         reg = DiscoveryServiceUtil.getRegistration
                                (discoverySrvc,
                                 new DiscoveryServiceUtil.BasicEventListener());
@@ -75,7 +76,8 @@ public class RenewLease extends Abstract
                                           ((getPreparedLease(reg)).getExpiration(),
                                            System.currentTimeMillis());
         logger.log(Level.FINE, "initial lease duration = "+duration);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      *  

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/RenewLeaseMap.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/RenewLeaseMap.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOn2SetGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOn2SetGroups.java Wed Jan  2 05:20:52 2013
@@ -32,6 +32,7 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that when the <code>setGroups</code> method is called
@@ -64,8 +65,8 @@ public class LateRegsNotifiedOn2SetGroup
      *  for properly configured lookup services, discard events, as well as
      *  discovery events will be generated.
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         logger.log(Level.FINE, "setup()");
         String[] allGroupsToDiscover = getGroupsToDiscover
                                                       (useOnlyGroupDiscovery);
@@ -84,7 +85,8 @@ public class LateRegsNotifiedOn2SetGroup
                 groups1[i-len0] = allGroupsToDiscover[i];
             }//end loop
         }//endif
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
@@ -92,13 +94,13 @@ public class LateRegsNotifiedOn2SetGroup
      *      service, requesting that NO_GROUPS and no locators be discovered
      * <li> calls setGroups, requesting the discovery of the 1st set of groups,
      *      which should equal the member groups of the 1st lookup service
      *      started in setup
      * <li> verifies that the discovery/discard process is working for the
      *      1st registration by waiting for the expected discovery and
      *      discard events
      * <li> calls setGroups, requesting the discovery of the 2nd set of groups,
      *      which should equal the member groups of the 2nd lookup service
      *      started in setup
      * <li> verifies that the discovery/discard process is working for the
      *      1st registration by waiting for the expected discovery and
      *      discard events
@@ -92,13 +94,13 @@ public class LateRegsNotifiedOn2SetGroup
      * <li> calls setGroups, requesting the discovery of the 1st set of groups,
      *      which should equal the member groups of the 1st lookup service
-     *      started in setup
+     *      started in construct
      * <li> verifies that the discovery/discard process is working for the
      *      1st registration by waiting for the expected discovery and
@@ -92,13 +94,13 @@ public class LateRegsNotifiedOn2SetGroup
      * <li> calls setGroups, requesting the discovery of the 2nd set of groups,
      *      which should equal the member groups of the 2nd lookup service
-     *      started in setup
+     *      started in construct
      * <li> verifies that the discovery/discard process is working for the
      *      1st registration by waiting for the expected discovery and

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOn2SetLocs.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOn2SetLocs.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOn2SetLocs.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOn2SetLocs.java Wed Jan  2 05:20:52 2013
@@ -32,6 +32,7 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that when the <code>setLocators</code> method is called
@@ -64,8 +65,8 @@ public class LateRegsNotifiedOn2SetLocs 
      *  for properly configured lookup services, discard events, as well as
      *  discovery events will be generated.
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         logger.log(Level.FINE, "setup()");
         LookupLocator[] allLocsToDiscover = getLocatorsToDiscover
                                                        (useOnlyLocDiscovery);
@@ -84,20 +85,21 @@ public class LateRegsNotifiedOn2SetLocs 
                 locs1[i-len0] = allLocsToDiscover[i];
             }//end loop
         }//endif
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
      * <li> create a first set of registration(s) with the lookup discovery
      *      service, requesting that NO_GROUPS and no locators be discovered
      * <li> calls setLocators, requesting the discovery of the locators of
      *      the lookup service(s) started in setup
      * <li> verifies that the discovery/discard process is working for the
      *      initial registration(s) by waiting for the expected discovery
      *      and discard events
      * <li> calls setLocators, requesting the discovery of the 2nd set of
      *      locators which should equal the locators of the 2nd lookup service
      *      started in setup
      * <li> verifies that the discovery/discard process is working for the
      *      initial registration(s) by waiting for the expected discovery and
      *      discard events
@@ -84,20 +85,21 @@ public class LateRegsNotifiedOn2SetLocs 
      *      service, requesting that NO_GROUPS and no locators be discovered
      * <li> calls setLocators, requesting the discovery of the locators of
-     *      the lookup service(s) started in setup
+     *      the lookup service(s) started in construct
      * <li> verifies that the discovery/discard process is working for the
      *      initial registration(s) by waiting for the expected discovery
@@ -84,20 +85,21 @@ public class LateRegsNotifiedOn2SetLocs 
      * <li> calls setLocators, requesting the discovery of the 2nd set of
      *      locators which should equal the locators of the 2nd lookup service
-     *      started in setup
+     *      started in construct
      * <li> verifies that the discovery/discard process is working for the
      *      initial registration(s) by waiting for the expected discovery and

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnAddGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/LateRegsNotifiedOnAddGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/CancelLeaseMap.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/CancelLeaseMap.java Wed Jan  2 05:20:52 2013
@@ -45,6 +45,7 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class determines if the lookup discovery service can, when requested
@@ -84,8 +85,8 @@ public class CancelLeaseMap extends Abst
      *  that each registration is valid)
      *  Constructs a LeaseMap that maps each lease to its current duration
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         /* Create the registrations */
         reg = new LookupDiscoveryRegistration[5];
         lease = new Lease[reg.length];
@@ -135,13 +136,14 @@ public class CancelLeaseMap extends Abst
                 }
             }
         }//end loop
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      *  
      *  1. Requests the cancellation of all leases referenced in the map
      *     constructed during setup
      *  2. For each lease granted during setup, verifies the lease is no
      *     longer valid by doing the following:
      *     a. attempts to retrieve the set of groups that the service
      *        will discover on behalf of the client; if the lease was
@@ -135,13 +136,14 @@ public class CancelLeaseMap extends Abst
      *  
      *  1. Requests the cancellation of all leases referenced in the map
-     *     constructed during setup
-     *  2. For each lease granted during setup, verifies the lease is no
+     *     constructed during construct
+     *  2. For each lease granted during construct, verifies the lease is no
      *     longer valid by doing the following:
      *     a. attempts to retrieve the set of groups that the service

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/LeaseExpiration.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/LeaseExpiration.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/LeaseExpiration.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/LeaseExpiration.java Wed Jan  2 05:20:52 2013
@@ -67,6 +67,7 @@ import net.jini.security.TrustVerifier;
 import net.jini.security.proxytrust.ServerProxyTrust;
 
 import com.sun.jini.proxy.BasicProxyTrustVerifier;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class determines if, when a client's lease on a registration with the
@@ -199,14 +200,14 @@ public class LeaseExpiration extends Abs
      *  Retrieve the set of group(s) with which the lookup service was started
      *  Create a handback object to help identify received discovery events
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         /* Start a lookup service */
         logger.log(Level.FINE, 
                           "starting a new lookup service");
         synchronized(eventLock) {
             eventReceived = false;
-            srvcReg = manager.startLookupService(); // already prepared
+            srvcReg = getManager().startLookupService(); // already prepared
             lookupList.add( srvcReg );
         }
         DiscoveryAdmin admin = DiscoveryAdminUtil.getDiscoveryAdmin(srvcReg);
@@ -218,13 +219,14 @@ public class LeaseExpiration extends Abs
 		   +GroupsUtil.toCommaSeparatedStr(memberGroups));
 	handback = new MarshalledObject
                               (GroupsUtil.toCommaSeparatedStr(memberGroups));
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      *  
      *  1. Request a registration with the lookup discovery service started
      *     during setup; requesting that the service discover lookup services
      *     belonging to the group(s) used during setup to start the lookup
      *     service 
      *  2. Pass the lease on the registration to a LeaseRenewalManager so
      *     the lease does not expire if the creation of the second lookup
@@ -234,7 +236,7 @@ public class LeaseExpiration extends Abs
      *     (this is done to demonstrate that the event mechanism of the
      *     lookup discovery service is functioning properly)
      *  4. Start a second lookup service belonging to the same group(s) as
      *     the lookup service started during setup
      *  5. Verify that the lookup discovery service sends another event
      *     announcing the discovery of a lookup service belonging to the
      *     group(s) used to start the lookup service just started (This is
@@ -251,7 +253,7 @@ public class LeaseExpiration extends Abs
      *  7. Verify that the lease has indeed expired by attempting to renew
      *     the lease
      *  8. Start a third lookup service belonging to the same group(s) as
      *     the lookup service started during setup
      *  9. Verify that the lookup discovery service does not send anymore
      *     discovery events to the registration's listener
      */
@@ -310,7 +312,7 @@ public class LeaseExpiration extends Abs
                           "starting a new lookup service");
         synchronized(eventLock) {
             eventReceived = false;
-	    srvcReg = manager.startLookupService(); // prepared
+	    srvcReg = getManager().startLookupService(); // prepared
             lookupList.add( srvcReg );
         }//end synchronized
         // prepared by DiscoveryAdminUtil
@@ -380,7 +382,7 @@ public class LeaseExpiration extends Abs
                           "starting a new lookup service");
         synchronized(eventLock) {
             eventReceived = false;
-	    srvcReg = manager.startLookupService(); // prepared
+	    srvcReg = getManager().startLookupService(); // prepared
             lookupList.add( srvcReg );
         }//end synchronized
 
@@ -218,13 +219,14 @@ public class LeaseExpiration extends Abs
      *  
      *  1. Request a registration with the lookup discovery service started
-     *     during setup; requesting that the service discover lookup services
-     *     belonging to the group(s) used during setup to start the lookup
+     *     during construct; requesting that the service discover lookup services
+     *     belonging to the group(s) used during construct to start the lookup
      *     service 
      *  2. Pass the lease on the registration to a LeaseRenewalManager so
@@ -234,7 +236,7 @@ public class LeaseExpiration extends Abs
      *     lookup discovery service is functioning properly)
      *  4. Start a second lookup service belonging to the same group(s) as
-     *     the lookup service started during setup
+     *     the lookup service started during construct
      *  5. Verify that the lookup discovery service sends another event
      *     announcing the discovery of a lookup service belonging to the
@@ -251,7 +253,7 @@ public class LeaseExpiration extends Abs
      *     the lease
      *  8. Start a third lookup service belonging to the same group(s) as
-     *     the lookup service started during setup
+     *     the lookup service started during construct
      *  9. Verify that the lookup discovery service does not send anymore
      *     discovery events to the registration's listener

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/RenewLease.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/RenewLease.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/RenewLeaseMap.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/lease/RenewLeaseMap.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import com.sun.jini.test.share.Discovery
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.discovery.LookupDiscoveryRegistration;
 
@@ -78,8 +79,8 @@ public class RenewLeaseMap extends Abstr
      *  Constructs a LeaseMap that maps each lease to the new duration
      *  that will be used in a renewal request.
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         /* Create the registrations */
         expectedDurations = getRenewalDurations();
         reg = new LookupDiscoveryRegistration[expectedDurations.length];
@@ -123,13 +124,14 @@ public class RenewLeaseMap extends Abstr
                 }
             }
         }//end loop
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      *  
      *  1. Requests the renewal of all leases referenced in the map
      *     constructed during setup
      *  2. For each lease granted during setup,
      *     a. retrieves the current expiration on the renewed lease
      *     b. converts the expiration to a duration, rounding to a whole value
      *     c. compares the value expected to the value returned
@@ -123,13 +124,14 @@ public class RenewLeaseMap extends Abstr
      *  
      *  1. Requests the renewal of all leases referenced in the map
-     *     constructed during setup
-     *  2. For each lease granted during setup,
+     *     constructed during construct
+     *  2. For each lease granted during construct,
      *     a. retrieves the current expiration on the renewed lease
      *     b. converts the expiration to a duration, rounding to a whole value

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSCET.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSCET.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSCET.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSCET.java Wed Jan  2 05:20:52 2013
@@ -36,6 +36,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.impl.mercury.EMSTestBase;
 import com.sun.jini.test.impl.mercury.TestUtils;
@@ -85,7 +86,7 @@ public class EMSCET extends EMSTestBase 
         
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	logger.log(Level.INFO, "Got TestGenerator ref {0}", myGen);
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,     	// Event ID to use
@@ -100,7 +101,7 @@ public class EMSCET extends EMSTestBase 
 
 	// Create two listener objects
 	TestListener myListener = 
-	    TestUtils.createDisableNSOListener(manager, mr);
+	    TestUtils.createDisableNSOListener(getManager(), mr);
 	logger.log(Level.INFO, "Got TestListener ref {0}", myListener);
 	int eventCount = 0;
 
@@ -147,12 +148,13 @@ public class EMSCET extends EMSTestBase 
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -147,12 +148,13 @@ public class EMSCET extends EMSTestBase 
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSCT.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSCT.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSCT.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSCT.java Wed Jan  2 05:20:52 2013
@@ -36,6 +36,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.impl.mercury.EMSTestBase;
 import com.sun.jini.test.impl.mercury.TestUtils;
@@ -84,7 +85,7 @@ public class EMSCT extends EMSTestBase i
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	logger.log(Level.INFO, "Got TestGenerator ref {0}", myGen);
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,     	// Event ID to use
@@ -98,7 +99,7 @@ public class EMSCT extends EMSTestBase i
 		    + new Date(tgl.getExpiration()));
 
 	// Create two listener objects
-	TestListener myListener = TestUtils.createDisableListener(manager, mr);
+	TestListener myListener = TestUtils.createDisableListener(getManager(), mr);
 	logger.log(Level.INFO, "Got TestListener ref {0}", myListener);
 	int eventCount = 0;
 
@@ -145,12 +146,13 @@ public class EMSCT extends EMSTestBase i
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -145,12 +146,13 @@ public class EMSCT extends EMSTestBase i
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSFT.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSFT.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSFT.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSFT.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import com.sun.jini.qa.harness.TestExcep
 import com.sun.jini.qa.harness.QAConfig;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxRegistration;
@@ -76,7 +77,7 @@ public class EMSFT extends EMSTestBase i
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,     	// Event ID to use
 			   null,  		// handback
@@ -87,7 +88,7 @@ public class EMSFT extends EMSTestBase i
 
 	// Create another event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen2 = TestUtils.createGenerator(manager);
+	TestGenerator myGen2 = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg2 = 
 	    myGen2.register(EVENT_ID2,     	// Event ID to use
 			    null,  		// handback
@@ -97,8 +98,8 @@ public class EMSFT extends EMSTestBase i
 	checkLease(tgl2, DURATION1); 
 
 	// Create two listener objects
-	TestListener myRel = TestUtils.createListener(manager);
-	TestListener myRel2 = TestUtils.createListener(manager);
+	TestListener myRel = TestUtils.createListener(getManager());
+	TestListener myRel2 = TestUtils.createListener(getManager());
 	int myRelCount = 0, myRelCount2 = 0;
 
 	// Generate some events from first generator
@@ -282,12 +283,13 @@ public class EMSFT extends EMSTestBase i
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -282,12 +283,13 @@ public class EMSFT extends EMSTestBase i
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSFT_PULL.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSFT_PULL.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSFT_PULL.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSFT_PULL.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import com.sun.jini.qa.harness.TestExcep
 import com.sun.jini.qa.harness.QAConfig;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.PullEventMailbox;
 import net.jini.event.MailboxPullRegistration;
@@ -80,7 +81,7 @@ public class EMSFT_PULL extends EMSTestB
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,     	// Event ID to use
 			   null,  		// handback
@@ -91,7 +92,7 @@ public class EMSFT_PULL extends EMSTestB
 
 	// Create another event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen2 = TestUtils.createGenerator(manager);
+	TestGenerator myGen2 = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg2 = 
 	    myGen2.register(EVENT_ID2,     	// Event ID to use
 			    null,  		// handback
@@ -101,7 +102,7 @@ public class EMSFT_PULL extends EMSTestB
 	checkLease(tgl2, DURATION1); 
 
 	// Create "listener" to collect events for this test
-	TestPullListener tpl = TestUtils.createPullListener(manager);
+	TestPullListener tpl = TestUtils.createPullListener(getManager());
 	int myTplCount = 0;
 
 	// Generate some events from first generator
@@ -188,12 +189,13 @@ public class EMSFT_PULL extends EMSTestB
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -188,12 +189,13 @@ public class EMSFT_PULL extends EMSTestB
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSIFT.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSIFT.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSIFT.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSIFT.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import com.sun.jini.qa.harness.QAConfig;
 import java.rmi.RemoteException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxRegistration;
@@ -105,12 +106,13 @@ public class EMSIFT extends MailboxTestB
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -105,12 +106,13 @@ public class EMSIFT extends MailboxTestB
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSIFT_PULL.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSIFT_PULL.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSIFT_PULL.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSIFT_PULL.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import com.sun.jini.qa.harness.QAConfig;
 import java.rmi.RemoteException;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.RemoteEventIterator;
 import net.jini.event.PullEventMailbox;
@@ -118,12 +119,13 @@ public class EMSIFT_PULL extends Mailbox
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -118,12 +119,13 @@ public class EMSIFT_PULL extends Mailbox
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLCT.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLCT.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLCT.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLCT.java Wed Jan  2 05:20:52 2013
@@ -37,6 +37,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.impl.mercury.EMSTestBase;
 import com.sun.jini.test.impl.mercury.TestUtils;
@@ -76,7 +77,7 @@ public class EMSLCT extends EMSTestBase 
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,     	// Event ID to use
 			   null,  		// handback
@@ -86,7 +87,7 @@ public class EMSLCT extends EMSTestBase 
 	checkLease(tgl, DURATION1); 
 
 	// Create two listener objects
-	TestListener myListener = TestUtils.createListener(manager);
+	TestListener myListener = TestUtils.createListener(getManager());
 	int eventCount = 0;
 
 	// Generate some events 
@@ -158,12 +159,13 @@ public class EMSLCT extends EMSTestBase 
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -158,12 +159,13 @@ public class EMSLCT extends EMSTestBase 
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLCT_PULL.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLCT_PULL.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLCT_PULL.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLCT_PULL.java Wed Jan  2 05:20:52 2013
@@ -38,6 +38,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.impl.mercury.EMSTestBase;
 import com.sun.jini.test.impl.mercury.TestUtils;
@@ -79,7 +80,7 @@ public class EMSLCT_PULL extends EMSTest
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,     	// Event ID to use
 			   null,  		// handback
@@ -89,7 +90,7 @@ public class EMSLCT_PULL extends EMSTest
 	checkLease(tgl, DURATION1); 
 
 	// Create "listener" to collect events for this test
-	TestPullListener tpl = TestUtils.createPullListener(manager);
+	TestPullListener tpl = TestUtils.createPullListener(getManager());
 	int eventCount = 0;
 
 	// Generate some events 
@@ -145,12 +146,13 @@ public class EMSLCT_PULL extends EMSTest
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -145,12 +146,13 @@ public class EMSLCT_PULL extends EMSTest
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLET.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLET.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLET.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLET.java Wed Jan  2 05:20:52 2013
@@ -36,6 +36,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.impl.mercury.EMSTestBase;
 import com.sun.jini.test.impl.mercury.TestUtils;
@@ -75,7 +76,7 @@ public class EMSLET extends EMSTestBase 
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,     	// Event ID to use
 			   null,  		// handback
@@ -85,7 +86,7 @@ public class EMSLET extends EMSTestBase 
 	checkLease(tgl, DURATION1); 
 
 	// Create two listener objects
-	TestListener myListener = TestUtils.createListener(manager);
+	TestListener myListener = TestUtils.createListener(getManager());
 	int eventCount = 0;
 
 	// Generate some events 
@@ -165,12 +166,13 @@ public class EMSLET extends EMSTestBase 
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -165,12 +166,13 @@ public class EMSLET extends EMSTestBase 
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST.java Wed Jan  2 05:20:52 2013
@@ -29,6 +29,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 public class EMSLST extends StressTest {
 
@@ -54,7 +55,7 @@ public class EMSLST extends StressTest {
 	}
 
 	// Creating event generators that use the mailbox listeners
-	TestGenerator[] myGen = TestUtils.createGenerators(NUM_REGS, manager);
+	TestGenerator[] myGen = TestUtils.createGenerators(NUM_REGS, getManager());
 	EventRegistration[] evtReg = new EventRegistration[NUM_REGS]; 
 	for (i = 0; i < NUM_REGS; i++) {
 	    evtReg[i] = myGen[i].register(
@@ -67,7 +68,7 @@ public class EMSLST extends StressTest {
 	}
 
 	// Create listener objects
-	TestListener[] listeners = TestUtils.createListeners(NUM_REGS, manager);
+	TestListener[] listeners = TestUtils.createListeners(NUM_REGS, getManager());
 
 	boolean sync = false;
 	boolean shutdown = false;
@@ -77,12 +78,13 @@ public class EMSLST extends StressTest {
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -77,12 +78,13 @@ public class EMSLST extends StressTest {
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST2.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST2.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST2.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST2.java Wed Jan  2 05:20:52 2013
@@ -29,6 +29,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 public class EMSLST2 extends StressTest {
 
@@ -54,7 +55,7 @@ public class EMSLST2 extends StressTest 
 	}
 
 	// Creating event generators that use the mailbox listeners
-	TestGenerator[] myGen = TestUtils.createGenerators(NUM_REGS, manager);
+	TestGenerator[] myGen = TestUtils.createGenerators(NUM_REGS, getManager());
 	EventRegistration[] evtReg = new EventRegistration[NUM_REGS]; 
 	for (i = 0; i < NUM_REGS; i++) {
 	    evtReg[i] = myGen[i].register(
@@ -67,7 +68,7 @@ public class EMSLST2 extends StressTest 
 	}
 
 	// Create listener objects
-	TestListener[] listeners = TestUtils.createListeners(NUM_REGS, manager);
+	TestListener[] listeners = TestUtils.createListeners(NUM_REGS, getManager());
 
 	boolean sync = false;
 	boolean shutdown = true;
@@ -77,12 +78,13 @@ public class EMSLST2 extends StressTest 
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -77,12 +78,13 @@ public class EMSLST2 extends StressTest 
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST3.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST3.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST3.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST3.java Wed Jan  2 05:20:52 2013
@@ -29,6 +29,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 public class EMSLST3 extends StressTest {
 
@@ -54,7 +55,7 @@ public class EMSLST3 extends StressTest 
 	}
 
 	// Creating event generators that use the mailbox listeners
-	TestGenerator[] myGen = TestUtils.createGenerators(NUM_REGS, manager);
+	TestGenerator[] myGen = TestUtils.createGenerators(NUM_REGS, getManager());
 	EventRegistration[] evtReg = new EventRegistration[NUM_REGS]; 
 	for (i = 0; i < NUM_REGS; i++) {
 	    evtReg[i] = myGen[i].register(
@@ -67,7 +68,7 @@ public class EMSLST3 extends StressTest 
 	}
 
 	// Create listener objects
-	TestListener[] listeners = TestUtils.createListeners(NUM_REGS, manager);
+	TestListener[] listeners = TestUtils.createListeners(NUM_REGS, getManager());
 
 	boolean sync = true;
 	boolean shutdown = false;
@@ -77,12 +78,13 @@ public class EMSLST3 extends StressTest 
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -77,12 +78,13 @@ public class EMSLST3 extends StressTest 
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST4.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST4.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST4.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSLST4.java Wed Jan  2 05:20:52 2013
@@ -29,6 +29,7 @@ import com.sun.jini.test.impl.mercury.Te
 import com.sun.jini.test.impl.mercury.TestGenerator;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 public class EMSLST4 extends StressTest {
 
@@ -56,7 +57,7 @@ public class EMSLST4 extends StressTest 
 	}
 
 	// Creating event generators that use the mailbox listeners
-	TestGenerator[] myGen = TestUtils.createGenerators(NUM_REGS, manager);
+	TestGenerator[] myGen = TestUtils.createGenerators(NUM_REGS, getManager());
 	EventRegistration[] evtReg = new EventRegistration[NUM_REGS]; 
 	for (i = 0; i < NUM_REGS; i++) {
 	    evtReg[i] = myGen[i].register(
@@ -69,7 +70,7 @@ public class EMSLST4 extends StressTest 
 	}
 
 	// Create listener objects
-	TestListener[] listeners = TestUtils.createListeners(NUM_REGS, manager);
+	TestListener[] listeners = TestUtils.createListeners(NUM_REGS, getManager());
 
 	boolean sync = true;
 	boolean shutdown = true;
@@ -79,12 +80,13 @@ public class EMSLST4 extends StressTest 
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -79,12 +80,13 @@ public class EMSLST4 extends StressTest 
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSNSOT.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSNSOT.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSNSOT.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSNSOT.java Wed Jan  2 05:20:52 2013
@@ -34,6 +34,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.impl.mercury.EMSTestBase;
 import com.sun.jini.test.impl.mercury.TestUtils;
@@ -71,7 +72,7 @@ public class EMSNSOT extends EMSTestBase
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,	// Event ID to use
 			   null,		// handback
@@ -81,9 +82,9 @@ public class EMSNSOT extends EMSTestBase
 	checkLease(tgl, DURATION1); 
 
 	// Create two listener objects
-	TestListener bad = TestUtils.createNSOListener(manager);
+	TestListener bad = TestUtils.createNSOListener(getManager());
 	int badCount = 0;
-	TestListener good = TestUtils.createListener(manager);
+	TestListener good = TestUtils.createListener(getManager());
 	int goodCount = 0;
 
 	// Generate some events from first generator
@@ -150,12 +151,13 @@ public class EMSNSOT extends EMSTestBase
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -150,12 +151,13 @@ public class EMSNSOT extends EMSTestBase
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRET.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRET.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRET.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRET.java Wed Jan  2 05:20:52 2013
@@ -34,6 +34,7 @@ import net.jini.core.event.RemoteEvent;
 import net.jini.core.event.RemoteEventListener;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.impl.mercury.EMSTestBase;
 import com.sun.jini.test.impl.mercury.TestUtils;
@@ -75,7 +76,7 @@ public class EMSRET extends EMSTestBase 
 
 	// Create an event generator and pass it the
 	// mailbox's remote event listener.
-	TestGenerator myGen = TestUtils.createGenerator(manager);
+	TestGenerator myGen = TestUtils.createGenerator(getManager());
 	EventRegistration evtReg = 
 	    myGen.register(EVENT_ID,	// Event ID to use
 			   null,		// handback
@@ -85,8 +86,8 @@ public class EMSRET extends EMSTestBase 
 	checkLease(tgl, DURATION1); 
 
 	// Create two listener objects
-	TestListener badListener = TestUtils.createREListener(manager);
-	TestListener goodListener = TestUtils.createListener(manager);
+	TestListener badListener = TestUtils.createREListener(getManager());
+	TestListener goodListener = TestUtils.createListener(getManager());
 	int badCount = 0;
 	int goodCount = 0;
 
@@ -179,12 +180,13 @@ public class EMSRET extends EMSTestBase 
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -179,12 +180,13 @@ public class EMSRET extends EMSTestBase 
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRIFT.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRIFT.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRIFT.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRIFT.java Wed Jan  2 05:20:52 2013
@@ -23,6 +23,7 @@ import com.sun.jini.qa.harness.TestExcep
 import com.sun.jini.qa.harness.QAConfig;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxRegistration;
@@ -65,7 +66,7 @@ public class EMSRIFT extends EMSTestBase
 		       "Was not able to re-submit service provided REL - OK");
 	}
 	// Pass our listener to the mailbox
-	TestListener myRel = TestUtils.createListener(manager);
+	TestListener myRel = TestUtils.createListener(getManager());
 	mr.enableDelivery(myRel);
 	assertCount(myRel, 0);
 	logger.log(Level.INFO, "Submitted our own REL");
@@ -98,12 +99,13 @@ public class EMSRIFT extends EMSTestBase
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -98,12 +99,13 @@ public class EMSRIFT extends EMSTestBase
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRIFT2.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRIFT2.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRIFT2.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/eventmailbox/EMSRIFT2.java Wed Jan  2 05:20:52 2013
@@ -23,6 +23,7 @@ import com.sun.jini.qa.harness.TestExcep
 import com.sun.jini.qa.harness.QAConfig;
 
 import com.sun.jini.constants.TimeConstants;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.event.EventMailbox;
 import net.jini.event.MailboxRegistration;
@@ -103,7 +104,7 @@ public class EMSRIFT2 extends EMSTestBas
 	}
 
 	// Pass our listener to the mailbox
-	TestListener myRel = TestUtils.createListener(manager);
+	TestListener myRel = TestUtils.createListener(getManager());
 	mr1.enableDelivery(myRel);
 	assertCount(myRel, 0);
 	mr2.enableDelivery(myRel);
@@ -150,12 +151,13 @@ public class EMSRIFT2 extends EMSTestBas
     }
 
     /**
      * Invoke parent's setup and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	parse();
+        return this;
     }
 }
@@ -150,12 +151,13 @@ public class EMSRIFT2 extends EMSTestBas
 
     /**
-     * Invoke parent's setup and parser
+     * Invoke parent's construct and parser
      * @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.